#ifndef HelpManager_h
#define HelpManager_h

// $Id: HelpManager.h,v 1.11 2013/02/14 09:02:44 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "File.h"
#include "HelpItem.h"

#include <QObject>
#include <QAction>

//! help manager class
namespace BASE
{

    class HelpManager:public QObject, public Counter
    {

        Q_OBJECT

        public:

        //! constructor
        HelpManager( QObject* parent );

        //! destructor
        virtual ~HelpManager( void )
        { Debug::Throw( "HelpManager::~HelpManager.\n" ); }

        //!@name accessors
        //@{

        //! install help. Put items in the menu, create associated objects
        void install( const HelpItem::List& items )
        { items_ = items; }

        //! install help. Put items in the menu, create associated objects
        void install( const QString text[], bool clear = true );

        //! list of items
        const HelpItem::List& items( void )
        { return items_; }

        //! clear help
        void clear( void )
        { items_.clear(); }

        //! set dialog caption
        void setWindowTitle( const QString& value );

        //@}

        //! display action
        QAction& displayAction( void )
        { return *displayAction_; }

        protected slots:

        //! opens help dialog
        void _display( void );

        private:

        //! dialog display action
        QAction* displayAction_;

        //! window title
        QString windowTitle_;

        //! complete set of help items
        HelpItem::List items_;

    };

};

#endif
